@@ -356,7 +356,8 @@ def api_build_post():
             return response, status
 
         req["store_path"] = current_app.config["STORE_PATH"]
-        req["cache_path"] = current_app.config.get("CACHE_PATH")
+        if current_app.config.get("CACHE_PATH"):
+            req["cache_path"] = current_app.config.get("CACHE_PATH")
         req["upstream_url"] = current_app.config["UPSTREAM_URL"]
         req["branch_data"] = current_app.config["BRANCHES"][req["branch"]]
         req["request_hash"] = request_hash
